aboutsummaryrefslogtreecommitdiffstats
path: root/code/api/src/Models/Static/AppEnvironmentVariables.cs
diff options
context:
space:
mode:
Diffstat (limited to 'code/api/src/Models/Static/AppEnvironmentVariables.cs')
-rw-r--r--code/api/src/Models/Static/AppEnvironmentVariables.cs47
1 files changed, 30 insertions, 17 deletions
diff --git a/code/api/src/Models/Static/AppEnvironmentVariables.cs b/code/api/src/Models/Static/AppEnvironmentVariables.cs
index c3f821d..0c1938d 100644
--- a/code/api/src/Models/Static/AppEnvironmentVariables.cs
+++ b/code/api/src/Models/Static/AppEnvironmentVariables.cs
@@ -2,20 +2,33 @@ namespace IOL.GreatOffice.Api.Data.Static;
public static class AppEnvironmentVariables
{
- /// <summary>
- /// An access token that can be used to access the Hashicorp Vault instance that is available at VAULT_URL
- /// </summary>
- public const string VAULT_TOKEN = "VAULT_TOKEN";
- /// <summary>
- /// An url pointing to the Hashicorp Vault instance the app should use
- /// </summary>
- public const string VAULT_URL = "VAULT_URL";
- /// <summary>
- /// The duration of which to keep a local cached version of the configuration
- /// </summary>
- public const string VAULT_CACHE_TTL = "VAULT_CACHE_TTL";
- /// <summary>
- /// The vault key name for the main configuration json object, described by <see cref="AppConfiguration"/>
- /// </summary>
- public const string MAIN_CONFIG_SHEET = "MAIN_CONFIG_SHEET";
-}
+ /// <summary>
+ /// An access token that can be used to access the Hashicorp Vault instance that is available at VAULT_URL
+ /// </summary>
+ public const string VAULT_TOKEN = "VAULT_TOKEN";
+
+ /// <summary>
+ /// A url pointing to the Hashicorp Vault instance the app should use
+ /// </summary>
+ public const string VAULT_URL = "VAULT_URL";
+
+ /// <summary>
+ /// The duration of which to keep a local cached version of the configuration
+ /// </summary>
+ public const string VAULT_CACHE_TTL = "VAULT_CACHE_TTL";
+
+ /// <summary>
+ /// The vault key name for the main configuration json object, described by <see cref="AppConfiguration"/>
+ /// </summary>
+ public const string MAIN_CONFIG_SHEET = "MAIN_CONFIG_SHEET";
+
+ /// <summary>
+ /// Tells the api to enable flight mode, only acts in DEBUG
+ /// </summary>
+ public const string FLIGHT_MODE = "FLIGHT_MODE";
+
+ /// <summary>
+ /// Tells the api where to read configuration from, defaults to flightmode.json, only acts in DEBUG
+ /// </summary>
+ public const string FLIGHT_MODE_JSON = "FLIGHT_MODE_JSON";
+} \ No newline at end of file